<?php
/**
 * curiosity functions and definitions
 *
 * @package curiosity-lite
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 600; /* pixels */
}

if ( ! function_exists( 'curiosity_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function curiosity_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on curiosity, use a find and replace
	 * to change 'curiosity-lite' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'curiosity-lite', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	
	if ( ! function_exists( 'curiosity_theme_support' ) ):
	function curiosity_theme_support() {
		$args = "";
		 add_theme_support( "custom-background", $args );
		 add_theme_support( "custom-header", $args );
	}
	endif;
	
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
        add_image_size('large-thumb', 1060, 650, true);
        add_image_size('index-thumb', 780, 350, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'curiosity-lite' ),
	) );

	// Setup the WordPress core custom background feature.
//	add_theme_support( 'custom-background', apply_filters( 'curiosity_custom_background_args', array(
//		'default-color' => 'ffffff',
//		'default-image' => '',
//	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
		'caption',
	) );
        
 /**
 * Editor Style
 */
        
function curiosity_add_editor_styles() {
    add_editor_style( 'custom-editor-style.css' );
}
add_action( 'init', 'curiosity_add_editor_styles' );
}

endif; // curiosity_setup
add_action( 'after_setup_theme', 'curiosity_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */

function curiosity_widgets_init() {	
	register_sidebar( array(
		'name'          => __( 'Sidebar 1', 'curiosity-lite' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s wow fadeIn animated">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Sidebar 2', 'curiosity-lite' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s wow fadeIn animated">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'curiosity-lite' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s wow fadeIn animated">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Sidebar 4', 'curiosity-lite' ),
		'id'            => 'sidebar-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s wow fadeIn animated">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Sidebar 5', 'curiosity-lite' ),
		'id'            => 'sidebar-5',
		'before_widget' => '<aside id="%1$s" class="widget %2$s wow fadeIn animated">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );   
	
	register_sidebar( array(
		'name'          => __( 'Footer 1', 'curiosity-lite' ),
		'id'            => 'footer-1',            
                'description'   => __( 'Footer widgets area appears in the footer of the site.', 'curiosity-lite'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer 2', 'curiosity-lite' ),
		'id'            => 'footer-2',            
                'description'   => __( 'Footer widgets area appears in the footer of the site.', 'curiosity-lite'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer 3', 'curiosity-lite' ),
		'id'            => 'footer-3',
                'description'   => __( 'Footer widgets area appears in the footer of the site.', 'curiosity-lite'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer 4', 'curiosity-lite' ),
                'id'            => 'footer-4',
                'description'   => __( 'Footer widgets area appears in the footer of the site.', 'curiosity-lite'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );     
}

add_action( 'widgets_init', 'curiosity_widgets_init' );

/**
 * Enqueue scripts and styles.
 */

function curiosity_scripts() {
		wp_enqueue_style( 'curiosity-style', get_stylesheet_uri() );
        
            if (is_page_template('page-templates/page-nosidebar.php')) {
                wp_enqueue_style( 'curiosity-layout-style' , get_template_directory_uri() . '/layouts/no-sidebar.css');
            } else if (is_page_template('page-templates/page-leftsidebar.php')) {
                wp_enqueue_style( 'curiosity-layout-style' , get_template_directory_uri() . '/layouts/left-sidebar.css');
            } else {
                wp_enqueue_style( 'curiosity-layout-style' , get_template_directory_uri() . '/layouts/content-sidebar.css');
            }
		
		wp_enqueue_style( 'bootstrap-style' , get_template_directory_uri() . '/css/bootstrap.css');

        wp_enqueue_style( 'font-awesome-style' , get_template_directory_uri() . '/css/font-awesome.css');
        
        wp_enqueue_style('curiosity-google-fonts', '//fonts.googleapis.com/css?family=Fondamento:400italic,400|PT+Serif:400,700,400italic,700italic|Playfair+Display:400,700,900,400italic,700italic,900italic');
		
		wp_enqueue_style( 'curiosity-color-style-1' , get_template_directory_uri() . '/css/color-styles/color_style_1.css');  
        
        /**
        * Enqueue scripts.
        */
		wp_enqueue_script( 'jquery' );
		
        wp_enqueue_script( 'curiosity-main', get_template_directory_uri() . '/js/main.js' );
        
		wp_enqueue_script( 'curiosity-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js' );
                
        wp_enqueue_script( 'curiosity-flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js');
        
        wp_enqueue_script( 'curiosity-easing', get_template_directory_uri() . '/js/jquery.easing.1.3.js');
		
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js');
        
        wp_enqueue_script( 'smooth-scroll', get_template_directory_uri() . '/js/smoothScroll.js');
        
        wp_enqueue_script( 'curiosity-marquee', get_template_directory_uri() . '/js/marquee.js');
		

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'curiosity_scripts' );

function curiosity_admin_script() {
	if (is_admin()) {		
		wp_enqueue_script('post-format-options', get_template_directory_uri() . '/js/post-format-options.js');
		wp_enqueue_style( 'curiosity-admin' , get_template_directory_uri() . '/css/curiosity-admin.css');
	}		
}
add_action('init', 'curiosity_admin_script');	

define('WEBZAKT_THEME_URL','http://webzakt.com/product/curiosity-responsive-newspaper-theme/','curiosity-lite');
define('WEBZAKT_THEME_DOC','http://webzakt.com/curiosity-documentation/','curiosity-lite');
define('WEBZAKT_LIVE_DEMO','http://webzakt.com/curiosity-responsive-newspaper-theme/','curiosity-lite');


/**
 * Customizer
 */
require get_template_directory() . '/inc/customizer.php';
	
/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Implement the Breadcrumbs feature.
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * About Theme
 */
require get_template_directory() . '/inc/about-theme.php';

/**
 * Plugin Activation
 */
require get_template_directory() . '/inc/plugin-activation.php';


// Metabox functions
if( class_exists('RW_Meta_Box') ) {
	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'video', 'gallery', 'link', 'quote' ) );
	/**
	 * Metabox feature
	*/       
	require get_template_directory() . '/inc/metabox.php';
}