<?php
/**
 * Curiosity Lite Customizer functionality
 *
 * @package curiosity-lite
 */

function curiosity_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	$wp_customize->add_section( 'general', array(
	  'title' => __( 'General', 'curiosity-lite' ),
	  'priority' => 22,
	  'capability' => 'edit_theme_options',
	) );

	$wp_customize->add_setting( 'body_background_color', array(
		'default'           => '#333333',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'body_background_color', array(
		'label'    => __( 'Body Background Color', 'curiosity-lite' ),
		'section'  => 'general',
		'settings'   => 'body_background_color',
		'description' => __( 'You can set the background color of the body. (Default is: #333)', 'curiosity-lite' ),
	) ) );
	
	$wp_customize->add_setting( 'body_background_image', array(
		'default'           => get_template_directory_uri() . '/images/patterns/wooden-pattern.png',
		'sanitize_callback' => 'esc_url_raw'
	) );
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'body_background_image', array(
		'label'    => __( 'Body Background Image', 'curiosity-lite' ),
		'section'  => 'general',
		'settings' => 'body_background_image',
		'description' => __( 'You can set the background image of the body. (It will be repeated)', 'curiosity-lite' ),
	) ) );
	
	$wp_customize->add_setting( 'default_read_more_text', array(
		'default'           => 'Read More',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'default_read_more_text', array(
		'label'    => __( 'Default Read More Text', 'curiosity-lite' ),
		'section'  => 'general',
		'settings' => 'default_read_more_text',
		'description' => __( 'Add text for the Read More buttons.', 'curiosity-lite' ),
	) ) );
	
	$wp_customize->add_section( 'header', array(
	  'title' => __( 'Header', 'curiosity-lite' ),
	  'priority' => 24,
	  'capability' => 'edit_theme_options',
	) );
	
	$wp_customize->add_setting( 'header_style', array(
		'default'	=> 'header_style_1',
		'sanitize_callback' => 'curiosity_sanitize_header_style',
	) );
	
	$wp_customize->add_control( 'header_style', array(
		'label'    => __( 'Header Style', 'curiosity-lite' ),
		'section'  => 'header',
		'type'     => 'select',
		'choices'  =>  array(
			'header_style_1'  => __( 'Style 1', 'curiosity-lite' ),
			'header_style_2' => __( 'Style 2', 'curiosity-lite' ),
			'header_style_2_parallax' => __( 'Style 2 Parallax', 'curiosity-lite' ),
		),
		'description' => __( 'Choose the style of the Header. Pick Style 1 if You would use Your logo only or pick the others, and You can use another image, next to Your logo section.', 'curiosity-lite' ),
		'priority' => 1,
	) );
	
	$wp_customize->add_setting( 'toplogo', array(
		'sanitize_callback' => 'esc_url_raw'
	) );
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'toplogo', array(
		'label'    => __( 'Top Logo', 'curiosity-lite' ),
		'section'  => 'header',
		'settings' => 'toplogo',
		'description' => __( 'Upload your logo.', 'curiosity-lite' ),
		'priority' => 2,
	) ) );
	
	$wp_customize->add_setting( 'allow_local_time', array(
		'default'	=> 'allow_local_time_yes',
		'sanitize_callback' => 'curiosity_sanitize_allow_local_time',
	) );
	
	$wp_customize->add_control( 'allow_local_time', array(
		'label'    => __( 'Display Local Time', 'curiosity-lite' ),
		'section'  => 'header',
		'type'     => 'select',
		'choices'  =>  array(
			'allow_local_time_yes'  => __( 'Yes', 'curiosity-lite' ),
			'allow_local_time_no' => __( 'No', 'curiosity-lite' ),
		),
		'description' => __( 'Display local time under Your logo (day/month/year).', 'curiosity-lite' ),
		'priority' => 3,
	) );
	
	$wp_customize->add_setting( 'display_email', array(
		'default'           => '',
		'sanitize_callback' => 'is_email',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'display_email', array(
		'label'    => __( 'Display Email Address', 'curiosity-lite' ),
		'section'  => 'header',
		'settings' => 'display_email',
		'description' => __( 'Display email address under the logo.', 'curiosity-lite' ),
		'priority' => 4,
	) ) );
	
	$wp_customize->add_setting( 'display_phone', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'display_phone', array(
		'label'    => __( 'Display Phone Number', 'curiosity-lite' ),
		'section'  => 'header',
		'settings' => 'display_phone',
		'description' => __( 'Display phone number under the logo.', 'curiosity-lite' ),
		'priority' => 5,
	) ) );
	
	$wp_customize->add_setting( 'header_advert', array(
		'sanitize_callback' => 'esc_url_raw'
	) );
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'header_advert', array(
		'label'    => __( 'Header Advert', 'curiosity-lite' ),
		'section'  => 'header',
		'settings' => 'header_advert',
		'description' => __( 'Upload Your image next to the logo for Style 2. (Parallax optimized for image with 800px width.)', 'curiosity-lite' ),
		'priority' => 6,
	) ) );
	
	$wp_customize->add_setting( 'header_advert_link', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'header_advert_link', array(
		'label'    => __( 'Header Advert Link', 'curiosity-lite' ),
		'section'  => 'header',
		'settings' => 'header_advert_link',
		'description' => __( 'You can add a link for the image.', 'curiosity-lite' ),
		'priority' => 7,
	) ) );
	
	$wp_customize->add_setting( 'breadcrumbs_activator', array(
		'default'	=> 'breadcrumbs_on',
		'sanitize_callback' => 'curiosity_sanitize_breadcrumbs_activator',
	) );
	
	$wp_customize->add_control( 'breadcrumbs_activator', array(
		'label'    => __( 'Breadcrumbs', 'curiosity-lite' ),
		'section'  => 'header',
		'type'     => 'select',
		'choices'  =>  array(
			'breadcrumbs_on'  => __( 'Breadcrumbs with Post Marquee', 'curiosity-lite' ),
			'breadcrumbs_text' => __( 'Breadcrumbs with Own Text', 'curiosity-lite' ),
			'breadcrumbs_only' => __( 'Only Breadcrumbs', 'curiosity-lite' ),
			'breadcrumbs_off' => __( 'Off', 'curiosity-lite' ),
		),
		'description' => __( 'Choose the style of the Breadcrumbs and Marquee section.', 'curiosity-lite' ),
		'priority' => 8,
	) );
	
	$wp_customize->add_setting( 'own_text_for_breadcrumbs', array(
		'default'           => '',
		'sanitize_callback' => 'esc_textarea',
	) );
	
	$wp_customize->add_control( 'own_text_for_breadcrumbs', array(
		'label'    => __( 'Own Text for Breadcrumbs', 'curiosity-lite' ),
		'section'  => 'header',
		'type'     => 'textarea',
		'settings' => 'own_text_for_breadcrumbs',
		'description' => __( 'Add Your own text.', 'curiosity-lite' ),
		'priority' => 9,
	) );
	
	$wp_customize->add_setting( 'header_padding', array(
		'default'           => '20',
		'sanitize_callback' => 'absint',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'header_padding', array(
		'label'    => __( 'Header Padding', 'curiosity-lite' ),
		'section'  => 'header',
		'settings' => 'header_padding',
		'description' => __( 'Add a number for the padding under and above the logo. (Without px)', 'curiosity-lite' ),
		'priority' => 10,
	) ) );
	
	$wp_customize->add_setting( 'curiosity_customcss', array(
		'default'           => '',
		'sanitize_callback' => 'wp_filter_nohtml_kses',
	) );
	
	$wp_customize->add_control( 'curiosity_customcss', array(
		'label'    => __( 'Custom CSS', 'curiosity-lite' ),
		'section'  => 'header',
		'type'     => 'textarea',
		'settings' => 'curiosity_customcss',
		'description' => __( 'Use this area to over ride any CSS from the stylesheet with custom CSS.', 'curiosity-lite' ),
		'priority' => 11,
	) );
	
	$wp_customize->add_section( 'top_header', array(
	  'title' => __( 'Top Header', 'curiosity-lite' ),
	  'priority' => 25,
	  'capability' => 'edit_theme_options',
	) );
	
	$wp_customize->add_setting( 'disable_top_header', array(
		'default'	=> 'top_header_only_home',
		'sanitize_callback' => 'curiosity_sanitize_disable_top_header',
	) );
	
	$wp_customize->add_control( 'disable_top_header', array(
		'label'    => __( 'Display Top Header', 'curiosity-lite' ),
		'section'  => 'top_header',
		'type'     => 'select',
		'choices'  =>  array(
			'top_header_only_home'  => __( 'Only at Front Page', 'curiosity-lite' ),
			'top_header_on' => __( 'On', 'curiosity-lite' ),
			'top_header_off' => __( 'Off', 'curiosity-lite' ),
		),
		'description' => __( 'You can switch off the Top Header section with this selector.', 'curiosity-lite' ),
		'priority' => 1,
	) );
	
	$wp_customize->add_setting( 'allow_on_mobile', array(
		'default'	=> 'on',
		'sanitize_callback' => 'curiosity_sanitize_allow_on_mobile',
	) );
	
	$wp_customize->add_control( 'allow_on_mobile', array(
		'label'    => __( 'Allow on Mobile and Tablet', 'curiosity-lite' ),
		'section'  => 'top_header',
		'type'     => 'select',
		'choices'  =>  array(
			'on'  => __( 'On', 'curiosity-lite' ),
			'off' => __( 'Off', 'curiosity-lite' ),
		),
		'description' => __( 'If You choose off, the Top Header section will disappear, if the screen is thinner than 900px.', 'curiosity-lite' ),
		'priority' => 2,
	) );
	
	$wp_customize->add_setting( 'column_1_title', array(
		'default'           => __( 'Lorem ipsum dolor sit amet, consectetuer.', 'curiosity-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_1_title', array(
		'label'    => __( 'Column 1 Title', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_1_title',
		'priority' => 3,
	) ) );
	
	$wp_customize->add_setting( 'column_1_text', array(
		'default'           => __( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit.', 'curiosity-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_1_text', array(
		'label'    => __( 'Column 1 Text', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_1_text',
		'priority' => 4,
	) ) );
	
	$wp_customize->add_setting( 'column_1_url', array(
		'default'           => '#',
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_1_url', array(
		'label'    => __( 'Column 1 URL', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_1_url',
		'priority' => 5,
	) ) );
	
	$wp_customize->add_setting( 'column_1_image', array(
		'sanitize_callback' => 'esc_url_raw'
	) );
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'column_1_image', array(
		'label'    => __( 'Column 1 Image', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_1_image',
		'description' => __( 'Upload Your image. (Optimized for transparent png.)', 'curiosity-lite' ),
		'priority' => 6,
	) ) );
	
	$wp_customize->add_setting( 'column_2_title', array(
		'default'           => __( 'Aenean commodo ligula eget dolor. Aenean massa. Donec pede justo.', 'curiosity-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_2_title', array(
		'label'    => __( 'Column 2 Title', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_2_title',
		'priority' => 7,
	) ) );
	
	$wp_customize->add_setting( 'column_2_text', array(
		'default'           => __( 'Nullam dictum felis eu pede mollis pretium. Integer tincidunt. Aenean massa.', 'curiosity-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_2_text', array(
		'label'    => __( 'Column 2 Text', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_2_text',
		'priority' => 8,
	) ) );
	
	$wp_customize->add_setting( 'column_2_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_2_url', array(
		'label'    => __( 'Column 2 URL', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_2_url',
		'priority' => 9,
	) ) );
	
	$wp_customize->add_setting( 'column_2_image', array(
		'sanitize_callback' => 'esc_url_raw'
	) );
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'column_2_image', array(
		'label'    => __( 'Column 2 Image', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_2_image',
		'description' => __( 'Upload Your image. (Optimized for transparent png.)', 'curiosity-lite' ),
		'priority' => 10,
	) ) );
	
	$wp_customize->add_setting( 'column_3_title', array(
		'default'           => __( 'Donec pede justo, aenean leo feugiat ligula.', 'curiosity-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_3_title', array(
		'label'    => __( 'Column 3 Title', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_3_title',
		'priority' => 11,
	) ) );
	
	$wp_customize->add_setting( 'column_3_text', array(
		'default'           => __( 'Cras dapibus. Vivamus elementum semper nisi. Aenean leo ligula.', 'curiosity-lite' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_3_text', array(
		'label'    => __( 'Column 3 Text', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_3_text',
		'priority' => 12,
	) ) );
	
	$wp_customize->add_setting( 'column_3_url', array(
		'default'           => '#',
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'column_3_url', array(
		'label'    => __( 'Column 3 URL', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_3_url',
		'priority' => 13,
	) ) );
	
	$wp_customize->add_setting( 'column_3_image', array(
		'sanitize_callback' => 'esc_url_raw'
	) );
	
	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'column_3_image', array(
		'label'    => __( 'Column 3 Image', 'curiosity-lite' ),
		'section'  => 'top_header',
		'settings' => 'column_3_image',
		'description' => __( 'Upload Your image. (Optimized for transparent png.)', 'curiosity-lite' ),
		'priority' => 14,
	) ) );
	
	$wp_customize->add_section( 'footer', array(
	  'title' => __( 'Footer', 'curiosity-lite' ),
	  'priority' => 26,
	  'capability' => 'edit_theme_options',
	) );
	
	$wp_customize->add_setting( 'footer_widgets', array(
		'default'	=> 'three_columns',
		'sanitize_callback' => 'curiosity_sanitize_footer_widgets',
	) );
	
	$wp_customize->add_control( 'footer_widgets', array(
		'label'    => __( 'Footer Widgets', 'curiosity-lite' ),
		'section'  => 'footer',
		'type'     => 'select',
		'choices'  =>  array(
			'three_columns'  => __( '3 columns', 'curiosity-lite' ),
			'four_columns' => __( '4 columns', 'curiosity-lite' ),
			'no_widgets' => __( 'No widgets', 'curiosity-lite' ),
		),
		'description' => __( 'Set the number of widget columns at footer.', 'curiosity-lite' ),
		'priority' => 1,
	) );
	
	$wp_customize->add_setting( 'color_of_footer', array(
		'default'	=> 'yellow',
		'sanitize_callback' => 'curiosity_sanitize_color_of_footer',
	) );
	
	$wp_customize->add_control( 'color_of_footer', array(
		'label'    => __( 'Color of Footer', 'curiosity-lite' ),
		'section'  => 'footer',
		'type'     => 'select',
		'choices'  =>  array(
			'transparent'  => __( 'Transparent', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'description' => __( 'Choose the color style of the footer.', 'curiosity-lite' ),
		'priority' => 2,
	) );
	
	$wp_customize->add_setting( 'curiosity_copyright', array(
		'default'           => '2016 Name of Company',
		'sanitize_callback' => 'wp_kses',
	) );
	
	$wp_customize->add_control( 'curiosity_copyright', array(
		'label'    => __( 'Copyright', 'curiosity-lite' ),
		'section'  => 'footer',
		'type'     => 'textarea',
		'settings' => 'curiosity_copyright',
		'description' => __( 'Enter your copyright information here that will appear on the center.  HTML such as links etc is acceptable.', 'curiosity-lite' ),
		'priority' => 3,
	) );
	
	$wp_customize->add_section( 'widget_colors', array(
	  'title' => __( 'Widget Colors', 'curiosity-lite' ),
	  'priority' => 111,
	  'capability' => 'edit_theme_options',
	) );
	
	$wp_customize->add_setting( 'default_widget_background_color', array(
		'default'	=> 'blue',
		'sanitize_callback' => 'curiosity_sanitize_w_color_b',
	) );
	
	$wp_customize->add_control( 'default_widget_background_color', array(
		'label'    => __( 'Default Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'description' => __( 'Choose the default background color of the widgets. At some of the widgets, You can pick individual colors.', 'curiosity-lite' ),
		'priority' => 1,
	) );
	
	$wp_customize->add_setting( 'archives_background_color', array(
		'default'	=> 'purple',
		'sanitize_callback' => 'curiosity_sanitize_w_color_p',
	) );
	
	$wp_customize->add_control( 'archives_background_color', array(
		'label'    => __( 'Archives Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'priority' => 2,
	) );
	
	$wp_customize->add_setting( 'calendar_background_color', array(
		'default'	=> 'none',
		'sanitize_callback' => 'curiosity_sanitize_w_color_n',
	) );
	
	$wp_customize->add_control( 'calendar_background_color', array(
		'label'    => __( 'Calendar Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'priority' => 3,
	) );
	
	$wp_customize->add_setting( 'categories_background_color', array(
		'default'	=> 'yellow',
		'sanitize_callback' => 'curiosity_sanitize_w_color_y',
	) );
	
	$wp_customize->add_control( 'categories_background_color', array(
		'label'    => __( 'Categories Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'priority' => 4,
	) );
	
	$wp_customize->add_setting( 'meta_background_color', array(
		'default'	=> 'purple',
		'sanitize_callback' => 'curiosity_sanitize_w_color_p',
	) );
	
	$wp_customize->add_control( 'meta_background_color', array(
		'label'    => __( 'Meta Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'priority' => 5,
	) );
	
	$wp_customize->add_setting( 'search_widget_background_color', array(
		'default'	=> 'none',
		'sanitize_callback' => 'curiosity_sanitize_w_color_n',
	) );
	
	$wp_customize->add_control( 'search_widget_background_color', array(
		'label'    => __( 'Search Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'priority' => 6,
	) );
	
	$wp_customize->add_setting( 'custom_menu_background_color', array(
		'default'	=> 'yellow',
		'sanitize_callback' => 'curiosity_sanitize_w_color_y',
	) );
	
	$wp_customize->add_control( 'custom_menu_background_color', array(
		'label'    => __( 'Custom Menu Background Color', 'curiosity-lite' ),
		'section'  => 'widget_colors',
		'type'     => 'select',
		'choices'  =>  array(
			'none'  => __( 'None', 'curiosity-lite' ),
			'blue' => __( 'Blue', 'curiosity-lite' ),
			'purple' => __( 'Purple', 'curiosity-lite' ),
			'yellow' => __( 'Yellow', 'curiosity-lite' ),
		),
		'priority' => 7,
	) );

}
add_action( 'customize_register', 'curiosity_customize_register', 11 );

function curiosity_sanitize_header_style( $sanitize_header_style ) {
    if ( ! in_array( $sanitize_header_style, array( 'header_style_1', 'header_style_2', 'header_style_2_parallax' ) ) ) { 
        $sanitize_header_style = 'header_style_1';
    }
    return $sanitize_header_style;
}

function curiosity_sanitize_allow_local_time( $allow_local_time ) {
    if ( ! in_array( $allow_local_time, array( 'allow_local_time_yes', 'allow_local_time_no' ) ) ) { 
        $allow_local_time = 'allow_local_time_yes';
    }
    return $allow_local_time;
}			

function curiosity_sanitize_breadcrumbs_activator( $breadcrumbs_activator ) {
    if ( ! in_array( $breadcrumbs_activator, array( 'breadcrumbs_on', 'breadcrumbs_text', 'breadcrumbs_only', 'breadcrumbs_off' ) ) ) { 
        $breadcrumbs_activator = 'breadcrumbs_on';
    }
    return $breadcrumbs_activator;
}
			
function curiosity_sanitize_disable_top_header( $disable_top_header ) {
    if ( ! in_array( $disable_top_header, array( 'top_header_only_home', 'top_header_on', 'top_header_off' ) ) ) { 
        $disable_top_header = 'top_header_only_home';
    }
    return $disable_top_header;
}

function curiosity_sanitize_allow_on_mobile( $allow_on_mobile ) {
    if ( ! in_array( $allow_on_mobile, array( 'on', 'off' ) ) ) { 
        $allow_on_mobile = 'on';
    }
    return $allow_on_mobile;
}

function curiosity_sanitize_footer_widgets( $footer_widgets ) {
    if ( ! in_array( $footer_widgets, array( 'three_columns', 'four_columns', 'no_widgets' ) ) ) { 
        $footer_widgets = 'three_columns';
    }
    return $footer_widgets;
}

function curiosity_sanitize_color_of_footer( $color_of_footer ) {
    if ( ! in_array( $color_of_footer, array( 'transparent', 'blue', 'purple', 'yellow' ) ) ) { 
        $color_of_footer = 'yellow';
    }
    return $color_of_footer;
}

function curiosity_sanitize_w_color_n( $w_color_n ) {
    if ( ! in_array( $w_color_n, array( 'none', 'blue', 'purple', 'yellow' ) ) ) { 
        $w_color_n = 'none';
    }
    return $w_color_n;
}

function curiosity_sanitize_w_color_b( $w_color_b ) {
    if ( ! in_array( $w_color_b, array( 'none', 'blue', 'purple', 'yellow' ) ) ) { 
        $w_color_b = 'blue';
    }
    return $w_color_b;
}

function curiosity_sanitize_w_color_p( $w_color_p ) {
    if ( ! in_array( $w_color_p, array( 'none', 'blue', 'purple', 'yellow' ) ) ) { 
        $w_color_p = 'purple';
    }
    return $w_color_p;
}

function curiosity_sanitize_w_color_y( $w_color_y ) {
    if ( ! in_array( $w_color_y, array( 'none', 'blue', 'purple', 'yellow' ) ) ) { 
        $w_color_y = 'yellow';
    }
    return $w_color_y;
}


function curiosity_customizer_css() {
    ?>
    <style type="text/css">
        body { background-color: <?php echo esc_html(get_theme_mod( 'body_background_color', '#333333' ));  ?>; background-image: url("<?php echo esc_url(get_theme_mod( 'body_background_image', get_template_directory_uri() . '/images/patterns/wooden-pattern.png' ));  ?>"); }
		.site-branding { padding: <?php echo absint(get_theme_mod( 'header_padding', '20' ));  ?>px 0; }
		<?php echo wp_strip_all_tags(get_theme_mod( 'curiosity_customcss' ));  ?>
    </style>
    <?php
}
add_action( 'wp_head', 'curiosity_customizer_css' );