<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package curiosity-lite
 */

if ( ! function_exists( 'curiosity_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @return void
 */

function curiosity_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	$format  = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link, 'index.php' ) ? 'index.php/' : '';
	$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%', 'paged' ) : '?paged=%#%';

	// Set up paginated links.
	$links = paginate_links( array(
		'base'     => $pagenum_link,
		'format'   => $format,
		'total'    => $GLOBALS['wp_query']->max_num_pages,
		'current'  => $paged,
		'mid_size' => 2,
		'add_args' => array_map( 'urlencode', $query_args ),
		'prev_text' => __( 'Previous', 'curiosity-lite' ),
		'next_text' => __( 'Next', 'curiosity-lite' ),
                'type'      => 'list',
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation">
		<h1 class="screen-reader-text"><?php _e( 'Posts navigation', 'curiosity-lite' ); ?></h1>
			<?php echo $links; ?>
	</nav><!-- .navigation -->
	<?php
	endif;
}
    
endif;

if ( ! function_exists( 'curiosity_post_nav' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @return void
 */
function curiosity_post_nav() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation">
            <div class="post-nav-box clear">
                <h1 class="screen-reader-text"><?php _e( 'Post navigation', 'curiosity-lite' ); ?></h1>
                <div class="nav-links">
                    <?php
                    previous_post_link( '<div class="nav-previous"><div class="nav-indicator">' . _x( 'Previous Post:', 'Previous post', 'curiosity-lite' ) . '</div><h1>%link</h1></div>', '%title' );
                    next_post_link(     '<div class="nav-next"><div class="nav-indicator">' . _x( 'Next Post:', 'Next post', 'curiosity-lite' ) . '</div><h1>%link</h1></div>', '%title' );
                    ?>
                </div><!-- .nav-links -->
            </div><!-- .post-nav-box -->
        </nav><!-- .navigation -->
	<?php
}
endif;



if ( ! function_exists( 'curiosity_top_header' ) ) :
/**
 * Display Curiosity Top Header.
 *
 * @return void
 */
function curiosity_top_header() {
	$column_1_image = esc_url(get_theme_mod( 'column_1_image' ));
	$column_1_title = sanitize_text_field(get_theme_mod( 'column_1_title', __( 'Lorem ipsum dolor sit amet, consectetuer.', 'curiosity-lite' ) ));
	$column_2_image = esc_url(get_theme_mod( 'column_2_image' ));
	$column_2_title = sanitize_text_field(get_theme_mod( 'column_2_title', __( 'Aenean commodo ligula eget dolor. Aenean massa. Donec pede justo.', 'curiosity-lite' ) ));
	$column_3_image = esc_url(get_theme_mod( 'column_3_image' ));
	$column_3_title = sanitize_text_field(get_theme_mod( 'column_3_title', __( 'Donec pede justo, aenean leo feugiat ligula.', 'curiosity-lite' ) ));
	$column_1_url = esc_url(get_theme_mod( 'column_1_url', '#' ));
	$column_2_url = esc_url(get_theme_mod( 'column_2_url' ));
	$column_3_url = esc_url(get_theme_mod( 'column_3_url', '#' ));
	$column_1_text = esc_html(get_theme_mod( 'column_1_text', __( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit.', 'curiosity-lite' ) ));
	$column_2_text = esc_html(get_theme_mod( 'column_2_text', __( 'Nullam dictum felis eu pede mollis pretium. Integer tincidunt. Aenean massa.', 'curiosity-lite' ) ));
	$column_3_text = esc_html(get_theme_mod( 'column_3_text', __( 'Cras dapibus. Vivamus elementum semper nisi. Aenean leo ligula.', 'curiosity-lite' ) ));  
	$allow_on_mobile = esc_html(get_theme_mod( 'allow_on_mobile', 'on' ));
	$readmoretext = esc_html(get_theme_mod( 'default_read_more_text', 'Read More' ));
	?>
            <div class="top-header<?php if ($allow_on_mobile == ('off')){ ?> no-display-on-mobile<?php } ?>">
                <div class="col-4 top-header-column-1">
                    <?php if ($column_1_image != ('')){ ?>
                    <?php if ($column_1_url != ('')){ ?><a href="<?php echo esc_url($column_1_url); ?>"><?php } ?><img src="<?php echo esc_url($column_1_image); ?>" class="header-column-image" alt="<?php echo esc_attr($column_1_title); ?>" /><?php if ($column_1_url != ('')){ ?></a><?php } ?>
                    <?php } ?>

                    <div class="header-column-content">
                        <?php if ($column_1_title != ('')){ ?><a href="<?php if ($column_1_url != ('')){ echo esc_url($column_1_url); } ?>"> 
                        <h3><?php echo esc_html($column_1_title); ?></h3></a><?php } ?>
                    <?php if ($column_1_text != ('')){ ?><p class="header-column-p"><?php echo esc_html($column_1_text); ?></p><?php } ?>
                    <?php if ($column_1_url != ('')) { ?><a href="<?php  echo esc_url($column_1_url);  ?>"  class="header-column-link"><span><?php echo esc_html($readmoretext) ; ?></span></a> <?php } ?>
                    </div>
                </div><!-- .top-header-column-1 --> 
                
                <div class="col-4 top-header-column-2" >                    
                    <?php if ($column_2_image != ('')){ ?>
                    <?php if ($column_2_url != ('')){ ?><a href="<?php echo esc_url($column_2_url); ?>"><?php } ?><img src="<?php echo esc_url($column_2_image); ?>" class="header-column-image" alt="<?php echo esc_attr($column_2_title); ?>" /><?php if ($column_2_url != ('')){ ?></a><?php } ?>
                    <?php } ?>
                    <div class="header-column-content">
                        <?php if ($column_2_title != ('')){ ?><a href="<?php if ($column_2_url != ('')){ echo esc_url($column_2_url); } ?>"> 
                        <h3><?php echo esc_html($column_2_title); ?></h3></a><?php } ?>
                    <?php if ($column_2_text != ('')){ ?><p class="header-column-p"><?php echo esc_html($column_2_text); ?></p><?php } ?>
                    <?php if ($column_2_url != ('')) { ?><a href="<?php  echo esc_url($column_2_url);  ?>"  class="header-column-link"><span><?php echo esc_html($readmoretext) ; ?></span></a> <?php } ?>
                    </div>
                </div><!-- .top-header-column-2 --> 
                                
                <div class="col-4 top-header-column-3" >
                    <?php if ($column_3_image != ('')){ ?>
                    <?php if ($column_3_url != ('')){ ?><a href="<?php echo esc_url($column_3_url); ?>"><?php } ?><img src="<?php echo esc_url($column_3_image); ?>" class="header-column-image" alt="<?php echo esc_attr($column_3_title); ?>" /><?php if ($column_3_url != ('')){ ?></a><?php } ?>
                    <?php } ?>

                    <div class="header-column-content">
                        <?php if ($column_3_title != ('')){ ?><a href="<?php if ($column_3_url != ('')){ echo esc_url($column_3_url); } ?>"> 
                        <h3><?php echo esc_html($column_3_title); ?></h3></a><?php } ?>
                    <?php if ($column_3_text != ('')){ ?><p class="header-column-p"><?php echo esc_html($column_3_text); ?></p><?php } ?>
                    <?php if ($column_3_url != ('')) { ?><a href="<?php  echo esc_url($column_3_url);  ?>"  class="header-column-link"><span><?php echo esc_html($readmoretext) ; ?></span></a> <?php } ?>
                    </div>
                </div><!-- .top-header-column-3 -->            
            </div><!-- .top-header -->
            <div class="clearfix"></div> 
	<?php
}
endif;

if ( ! function_exists( 'curiosity_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function curiosity_posted_on() {
	$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	printf( __( '<span class="line">Written by %2$s</span><span class="posted-on"> %1$s</span>', 'curiosity-lite' ),
		sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
			esc_url( get_permalink() ),
			$time_string
		),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s">%2$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		)
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 */
function curiosity_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so curiosity_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so curiosity_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in curiosity_categorized_blog.
 */
function curiosity_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'all_the_cool_cats' );
}
add_action( 'edit_category', 'curiosity_category_transient_flusher' );
add_action( 'save_post',     'curiosity_category_transient_flusher' );


